CHANGES
=======

0.3.2 (2015-10-28)
------------------

* Python 2.7, 3.2, 3.3, 3.4, 3.5 support
* pandas 0.14, 0.15, 0.16, 0.17 support

0.3.1 (2015-10-28)
------------------

* Update support python version
* Update dependencies library version

0.3.0 (2015-07-15)
------------------

* Critical bug fix

0.2.0 (2015-05-24)
------------------

* Support char type validation
* flake8 testing

0.1.0 (2015-05-22)
------------------

Initial release.

* Support integer series validator
* Support float series validator
* Support dataframe validator

* Testing on python2.7 and python 3.4

0.0.0 (2015-05-17)
------------------

Create this project.

